function  dy = E2F1_STAT3_IL6_2024Mar03(t,y)
%
% Global variables
    global St E2F1 k0 kmir
%
% Number of ODE equations
    dy=zeros(5,1);
%
% Model parameters
%
    k1= 3;                   % Activation rate of STAT3, taken from PMID: 24082147
    %
    k2= -log(0.5)/1;         % Half-life of activated STAT3 1 hr, taken from PMID: 24082147
    %
    k3= -log(0.5)/0.5;       % Half-life of IL6 mRNA 0.5 hr, taken from PMID: 16954375
    %
    k4= -log(0.5)/4;         % Half-life of IL6 4 hr, taken from PMID: 20376398
    %
    k5= 6;                   % Activation rate of J6R, tuned based on PMID: 7812050 for high sensitivity to IL-6
    %
    k6= -log(0.1)/1;         % 0.9-life of J6RS, taken from PMID: 7812050
    %
    k7= -log(0.5)/2.5;       % Half-life of J6R complex with/without activation 2.5 hr, taken from PMID: 8033901
    %
    g1= 2;                   % kinetic order of J6R in JAK2/ILR-6 complex activation (hexamer with double JAK2, IL-6R and gp130) assumed based on PMID: 9716487
    %
    g2= 2;                   % kinetic order of IL-6 in JAK2/ILR-6 complex activation (hexamer with double JAK2, IL-6R and gp130) assumed based on PMID: 9716487
%
% Time-dependent variables
    J6R=y(1);     % Inactive JAK2/ILR-6 complex
    J6RS=y(2);    % Active JAK2/ILR-6 complex
    DS=y(3);      % Dimeric phosphorilated STAT3
    mIL6=y(4);    % IL-6 mRNA
    IL6=y(5);     % IL-6
%
% Sigmoidal Hill-equation transcriptional activation IL-6
    % Input variables
        E2F1m2_1=0.25;   E2F1m2_2=1.0;   Vfm21=0.05;       Vfm22=0.25;
    % Equations
        RatioE2F1m2=E2F1m2_1/E2F1m2_2;   Dm21=(1-Vfm21)/Vfm21; Dm22=(1-Vfm22)/Vfm22; RatioVm2=Dm21/Dm22;
        Inv_gm2=-log10(RatioE2F1m2)/log10(RatioVm2);
    % parameters
        h=1/Inv_gm2;        km=E2F1m2_1*Dm21^Inv_gm2;
%
% Model equations
%   J6R
       dy(1) = - 2.*k5.*J6R.^g1.*IL6.^g2 + 2.*k6.*J6RS + k7.*( 1 - J6R);
%   J6RS
      dy(2) = k5.*J6R.^g1.*IL6.^g2 - k6.*J6RS - k7.*J6RS;
%   DS
      dy(3) = k1.*(J6RS + k0).*(St - 2.*DS).^2 - k2.*DS;
      %dy(3) = k1.*k0.*(St - 2*DS).^1 - 0.*k2.*DS;
%   mIL6
      dy(4)= k3.*( ((E2F1.*DS).^h)./(km.^h + (E2F1.*DS).^h) - (1 + kmir).*mIL6);
%   IL6
      dy(5)= k4.*( mIL6 - IL6);

