%
clear
% Loading of relevant data
    load IL6_vector.txt  % IL-6 values taken from the iterative simulations of E2F1_STAT3_IL6_2024Feb28_melanoma, in which we modified E2F1 levels.
%
% Global variables
    global k0 kmir IL6mc E2F1 Il6_auloop
%
% Timing of simulation
      ti=0;       % initial time
      tf=100;    % final time
      timeint=ti:.5:tf;
%
%  Global Parameters
      k0 = 0.0;       % STAT3 activaton via cross-talk with IL-6R independent pathways;
      kmir = 0.0;     % miRNA-mediated repression of IL-6
      E2F1 = 1.0;     % E2F expression
      Il6_auloop = 1; % IL-6 autocrine loop, 1 means activated
%
%
% Initial condition: We assumed the regulatorey pathway inactive (OFF) at the beginning of the simulation
      J6R01 = 2.0;   % all IL-6R complex inactive
      J6RS01 = 0.;
      DS01 = 0.;
      mIL1001 = 0.;
      IL1001 = 0.;
      mIL601 = 0.;
      IL601 = 0.;
      x0off= [ J6R01 J6RS01 DS01 mIL1001 IL1001 mIL601 IL601 ];
%
% Iterative simulations
  for i=1:length(IL6_vector)
      length(IL6_vector) - i
      % Tuned parameter: IL-6 values taken from the iterative simulation of E2F1_STAT3_IL6_2024Feb28_melanoma modifying E2F1 levels. Values stored in IL6_vector.txt
      IL6mc= IL6_vector(i);
      %
      %
      % Steady state from OFF configuration
      clear t soloff
      % Simulation
            [t,soloff] = ode45(@E2F1_STAT3_IL6_2024Feb28_CD4T_FL,timeint,x0off);
      %
      % Lenght time vector
          numtimef=length(timeint);
      % Value of readouts at final timnepoint
          IL10_vector(i)= soloff(numtimef,5);         % IL-6
          IL6_Tcells_vector(i) = soloff(numtimef,7);  % IL-10
  end
%
% Values of E2F12 expression as modified in the iterative simulation of E2F1_STAT3_IL6_2024Feb28_melanoma
      logval_vector= -1:0.01:2;
      E2F1_vector = 10.^logval_vector;
%
%   Plot of the IL-10 results
          figure('units', 'centimeters', 'position', [2 2 8 5.], ...
              'paperunits', 'centimeters', 'paperposition', [2 2 8 5.], ...
              'paperpositionmode', 'auto');
          axes('position', [.2 .25 .75 .7], 'fontsize', 9, 'box', 'on')
          %p53(1,1)=0;
          plot(E2F1_vector,IL10_vector);
          %surf(k9matrix,k7matrix,ApoC48,'Edgecolor','none');
          %colormap(jet)
          axis([0.1 100 -0.05 0.4]);
          %set(gca,'xtick',[0.1 1 10 100],'ytick',[0.1 1 10]);
          set(gca,'xtick',[0.1 1 10 100]);
          set(gca,'XScale','log','fontsize',9);
               % view([0 0 1])
          xlabel('E2F1 (a.u.)');
          ylabel('IL-10 (a.u.)');
%
%   Plot of the IL-6 results
          figure('units', 'centimeters', 'position', [2 2 8 5.], ...
              'paperunits', 'centimeters', 'paperposition', [2 2 8 5.], ...
              'paperpositionmode', 'auto');
          axes('position', [.2 .25 .75 .7], 'fontsize', 9, 'box', 'on')
          %p53(1,1)=0;
          plot(E2F1_vector,IL6_Tcells_vector);
          %surf(k9matrix,k7matrix,ApoC48,'Edgecolor','none');
          %colormap(jet)
          axis([0.1 100 -0.05 1.0]);
          %set(gca,'xtick',[0.1 1 10 100],'ytick',[0.1 1 10]);
          set(gca,'xtick',[0.1 1 10 100]);
          set(gca,'XScale','log','fontsize',9);
               % view([0 0 1])
          xlabel('E2F1 (a.u.)');
          ylabel('IL-6 (a.u.)');
