%
clear
%
% Global variables
    global St E2F1 k0 kmir
%
% Timing of simulation
      ti=0;       % initial time
      tf=100;    % final time
      timeint=ti:.5:tf;
%
%  Global Parameters
      St = 1;       % Total STAT3;
      k0 = 0.025;   % STAT3 activaton via cross-talk with IL6R independent pathways;
      kmir = 0.0;   % RmiRNA-mediated repression of IL6
      %


      logval_vector= -1:0.05:1;
      E2F1_vector = 10.^logval_vector;
      STAT3_vector = 10.^logval_vector;
%
%
% Initial condition: We assumed the regulatory pathway inactive (OFF) at the beginning of the simulation
      %
      J6R01 = 1;
      J6RS01 = 0.;
      DS01 = 0.;
      mIL601 = 0.;
      IL601 = 0.;
      x0off= [ J6R01 J6RS01 DS01 mIL601 IL601 ];
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% One parameter iterative simulations
% We iteratively change the values of E2F1 expression n the model
% and perform model simulations to compute values of IL-6
%
% Vector for iterative simulation
      logval_vector= -1:0.05:2;
      E2F1_vector = 10.^logval_vector;
%
  for i=1:length(E2F1_vector)
      i;
      % Tuned parameter: E2F1 espression level
          E2F1= E2F1_vector(i);
      %
      % Steady state from OFF configuration
          clear t soloff
      % Simulation
          [t0,soloff]=ode45(@E2F1_STAT3_IL6_2024Mar03,timeint,x0off);
      %
      % Lenght time vector
          numtimef=length(timeint);
      % Value of IL6 at final timnepoint
          IL6_vector(i)= soloff(numtimef,5);
 end
 %
 %   Plot of the IL6ss results
        figure('units', 'centimeters', 'position', [2 2 8 5.], ...
            'paperunits', 'centimeters', 'paperposition', [2 2 8 5.], ...
            'paperpositionmode', 'auto');
        axes('position', [.2 .25 .75 .7], 'fontsize', 9, 'box', 'on')
        plot(E2F1_vector,IL6_vector);
        axis([0.1 100 -0.05 1]);
        set(gca,'xtick',[0.1 1 10 100]);
        set(gca,'XScale','log','fontsize',9);
        xlabel('E2F1 (a.u.)');
        ylabel('IL6 (a.u.)');
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Two-parameters iterative simulations
% We iteratively change the values of E2F1 expression and total STAT3 in the model
% and perform model simulations to compute values of IL-6
%
% Vector for iterative simulation
      logval_vector= -1:0.05:1;
      E2F1_vector = 10.^logval_vector;
      STAT3_vector = 10.^logval_vector;
%
% Set up of a countdown
    z=length(E2F1_vector).*length(STAT3_vector);
%
% Double loop
  for i=1:length(E2F1_vector)
    for j=1:length(STAT3_vector)
      % Countdown
        z= z -1
      % Assign vaues to the two tuned parameters
        E2F1 = E2F1_vector(i);
          E2F1matrix(i,j) = E2F1;
        St = STAT3_vector(j);
          STAT3matrix(i,j) = St;
      %
      % Steady state from OFF configuration
        clear t soloff
      % Simulation
        [t0,soloff]=ode45(@E2F1_STAT3_IL6_2024Mar03,timeint,x0off);
      %
      % Lenght time vector
          numtimef=length(timeint);
      % Value of IL6 at final timnepoint stored in matrix
        IL6matrix(i,j)= soloff(numtimef,5);
    end
end
 %
 %   Plot of the IL6ss results
        figure('units', 'centimeters', 'position', [2 2 8 8], ...
            'paperunits', 'centimeters', 'paperposition', [2 2 8 8], ...
            'paperpositionmode', 'auto');
        axes('position', [.20 .20 .70 .70], 'fontsize', 10, 'box', 'on')
        surf(E2F1matrix,STAT3matrix,IL6matrix,'Edgecolor','none');
        colormap(jet)
        %axis([ddmin ddmax mirmin mirmax 0 5]);
        %set(gca,'xtick',[0.1 1 10],'ytick',[0.1 1 10]);
        %set(gca,'XScale','log','fontsize',8.);
        %set(gca,'YScale','log','fontsize',8.);
        view([0 0 1 ]);
        xlabel('E2F1');
        ylabel('STAT3');
        title('IL-6 melanoma','Fontsize',10);
        hcb=colorbar('location','eastOutside','Fontsize',9);
